import Bugsnag from '@bugsnag/js';
import fp from 'fastify-plugin';
function extractRequestMetadata(request) {
    return {
        body: request.body,
        clientIp: request?.ips?.[0] ?? request.ip,
        headers: request.raw.headers,
        httpMethod: request.routerMethod,
        params: request.params,
        path: request.routerPath,
        query: request.query,
        referer: request.raw.headers.referer,
        url: request.url
    };
}
function obtainRequestAndMetadataInfo(request) {
    const metadata = extractRequestMetadata(request);
    return {
        metadata,
        request: {
            clientIp: metadata.clientIp,
            headers: metadata.headers,
            httpMethod: metadata.httpMethod,
            referer: metadata.referer,
            url: metadata.url
        }
    };
}
function bugsnagPlugin(fastify, options, done) {
    Bugsnag.start(options);
    fastify.decorate('bugsnag', Bugsnag);
    fastify.decorateRequest('bugsnag', null);
    fastify.addHook('onRequest', function decorateRequestInstance(request, reply, next) {
        request.bugsnag = Bugsnag;
        next();
    });
    fastify.addHook('onError', async function bugsnagErrorHandlerPlugin(request, reply, error) {
        this.bugsnag.notify(error, event => {
            const { metadata, request: requestData } = obtainRequestAndMetadataInfo(request);
            event.request = requestData;
            event.addMetadata('request', metadata);
        });
    });
    done();
}
export default fp(bugsnagPlugin, {
    fastify: '4.x',
    name: 'fastify-bugsnag'
});
//# sourceMappingURL=index.js.map